#|

This file contains only functions that are called from SD Dialogs. 
Each function should be documented with it's purpose as well as
all of the Dialogs that use it.  Complex machining operations.

12-Nov-99  Found that these operations only work with the active part.  The dialog allows that part to be changed, but it has no effect.  The
fix is to add an "after-input" statement to the dialog macro.

To make use of these functions, the calling Dialogs must use the 
in-package LHC.

|#

;; Last modified    : 24-Jun-2000
;; Category         : Utilities/Functions
;; Author           : Bruce Fisher (bfisher@lhcarbide.com)
;; Company          : L.H. Carbide Corporation
;; Filename         : functions.lsp
;; Calling Dialogs  : lhc_hl_bore, lhc_hl_drill, lhc_hl_punch
;; SD Revision      : 7.11,7.51
;; Platform         : Windows NT 4.0

(in-package :LHC)
(use-package :OLI)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Last modified    : 13-Nov-1999
;; Category         : Utilities/Functions
;; Company          : L.H. Carbide Corporation
;; Author           : Bruce Fisher
;; Function Name    : drill_hl
;; SD Revision	  : 7.51
;; Function Rev.	  : 1.10
;; Parameters       : Location point, Depth of full diameter, Diameter
;; Purpose          : create a hole with a standard drill point
;; Calling Dialogs  : lhc_hl_drill
;; Comments         :

 (defun drill_hl (A_PRT P1 DP1 DIA)
   (setq curr_wp (sd-inq-curr-wp))
   (setq curr_prt a_prt)
   (setq ang_fact (tan (* (/ (* 2 pi) 360.0) 31.0))) ;calculate tan 31 in degrees
   (setq dr_pnt (+ dp1 (* (/ dia 2.0) ang_fact)))  ;depth of drill point

     (sd-call-cmds 
       (CREATE_WORKPLANE 
                         :copy
                         :name "hl_drill.wp"
                         :source curr_wp)) 

;; The newly created workplane is created under the root by default so
;; the root "/" has to be part of the workplane name.  It is desirable
;; to slide the origin of the workplane before rotating it so that the
;; drilling operation is easy to calculate.

;; Wrong.  WP is created under selected assembly, which may not be root

    (slide_wp_origin (sd-inq-curr-wp) p1) 
    (position_wp (sd-inq-curr-wp)
           :rotate
           :axis
           :u
           :rotation_angle 90.0
           :done 
      )

;; get rid of baggage profiles first 

(del_2d_geo (sd-inq-curr-wp))

;; Now build the profile from user inputs
  (geometry_mode :real) ;ndert die Geometrieart auf "Geometrie" falls das nicht eingestellt ist
    (polygon
    (gpnt2d 0 1.0)
    (gpnt2d (/ dia 2.0) 1.0)
    (gpnt2d (/ dia 2.0) (* -1.0 dp1))
    (gpnt2d 0 (* -1.0 dr_pnt)) 
    :close) 

;; Profile is built.  Now run the bore tool.  

    (sd-call-cmds
    (bore  :parts curr_prt
           :axis 
           :v
           :keep_wp :no
           :keep_profile :no)
     )
 (current_wp curr_wp)  ; Set workplane back to original
)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;; Last modified     : 09-10-2001
;; Category          : Utilities/Functions
;; Company           : PTB-Braunschweig
;; Author            : Michael Mller
;; Function Name     : kegel_bohren
;; Parameters        : Location point, Depth of bore, Diameter
;; Purpose           : Bohren einer Senkung fr Senkkopfschrauben mit 90
;; SD Revision       : 8.01
;; Function Rev.     : 1.00
;; Calling Dialogs   : 
;; Comments          :
 
 (defun bohre_senk (A_PRT P1 DP1 DIA) ; bernahme der Variablen: a_part, pnt_1, senk_tf, senk_dm aus Kegelsenkung.lsp
   (setq curr_wp (sd-inq-curr-wp))
   (setq curr_prt a_prt)

     (sd-call-cmds 
       (CREATE_WORKPLANE 
                         :copy
                         :name "bohre_senk.wp"
                         :source curr_wp)) 

;; The newly created workplane is created under the root by default so
;; the root "/" has to be part of the workplane name.  It is desirable
;; to slide the origin of the workplane before rotating it so that the
;; boring operation is easy to calculate.

    (slide_wp_origin (sd-inq-curr-wp) P1) 
    (position_wp (sd-inq-curr-wp)
           :rotate
           :axis
           :u
           :rotation_angle 90.0
           :done 
      )

;; 2D-Profil nach Benutzervorgaben erstellen


;; berflssige 2D-Geometrie lschen

(del_2d_geo (sd-inq-curr-wp))

 (geometry_mode :real) ;ndert die Geometrieart auf "Geometrie" falls das nicht eingestellt ist
    ; Erstellen des 3-Ecks
    (polygon
    (gpnt2d 0 1.0)
    (gpnt2d (/ dia 2.0) 1.0)
    (gpnt2d (/ dia 2.0) (* -1 dp1))
    (gpnt2d 0 (* -1 (+ dp1 (/ dia 2.0))))
    :close) 

;; Profil fertig, jetzt abdrehen...

    (sd-call-cmds
    (bore  :parts curr_prt
           :axis 
           :v
           :rotation_angle (* 2 pi)
           :keep_profile :no
           :keep_wp :no)
     )
 (current_wp curr_wp)  ; Set workplane back to original
)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Last modified     : 13-Nov-1999
;; Category          : Utilities/Functions
;; Company           : L.H. Carbide Corporation
;; Author            : Bruce Fisher
;; Function Name     : punch_hl
;; Parameters        : Location point, Diameter
;; Purpose           : Punch a hole through a part.
;; SD Revision	   : 7.51
;; Function Revision : 1.10
;; Calling Dialogs   : lhc_hl_pch
;; Comments          :
   
   (defun punch_hl (A_PRT P1 DIA)
   (setq curr_wp (sd-inq-curr-wp))
   (setq curr_prt a_prt)

     (sd-call-cmds 
       (CREATE_WORKPLANE 
                         :copy
                         :name "hl_pch.wp"
                         :source curr_wp)) 

;; get rid of baggage profiles first 

(del_2d_geo (sd-inq-curr-wp))

  (geometry_mode :real) ;ndert die Geometrieart auf "Geometrie" falls das nicht eingestellt ist
    (circle :cen_rad P1 (/ DIA 2))
    (sd-call-cmds
    (punch :parts curr_prt
           :keep_wp :no
           :keep_profile :no)
     )
 (current_wp curr_wp)  ; Set workplane back to original
)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Last modified     : 13-Nov-1999
;; Category          : Utilities/Functions
;; Company           : L.H. Carbide Corporation
;; Author            : Bruce Fisher
;; Function Name     : bore_hl
;; Parameters        : Location point, Depth of bore, Diameter
;; Purpose           : Bore a flat bottomed hole in a part.
;; SD Revision   	   : 7.51
;; Function Rev.	   : 1.10
;; Calling Dialogs   : lhc_hl_bore
;; Comments          :
 
 (defun bore_hl (A_PRT P1 DP1 DIA)
   (setq curr_wp (sd-inq-curr-wp))
   (setq curr_prt a_prt)

     (sd-call-cmds 
       (CREATE_WORKPLANE 
                         :copy
                         :name "hl_bore.wp"
                         :source curr_wp)) 

;; The newly created workplane is created under the root by default so
;; the root "/" has to be part of the workplane name.  It is desirable
;; to slide the origin of the workplane before rotating it so that the
;; boring operation is easy to calculate.

    (slide_wp_origin (sd-inq-curr-wp) P1) 
    (position_wp (sd-inq-curr-wp)
           :rotate
           :axis
           :u
           :rotation_angle 90.0
           :done 
      )

;; Now build the profile from user inputs


;; get rid of baggage profiles first 

(del_2d_geo (sd-inq-curr-wp))

 (geometry_mode :real) ;ndert die Geometrieart auf "Geometrie" falls das nicht eingestellt ist
    (polygon
    (gpnt2d 0 1.0)
    (gpnt2d (/ dia 2.0) 1.0)
    (gpnt2d (/ dia 2.0) (* -1.0 dp1))
    (gpnt2d 0 (* -1.0 dp1)) 
    :close) 

;; Profile is built.  Now run the bore tool.  

    (sd-call-cmds
    (bore  :parts curr_prt
           :axis 
           :v
           :rotation_angle (* 2 pi)
           :keep_wp :no
           :keep_profile :no)
     )
 (current_wp curr_wp)  ; Set workplane back to original
)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Last modified     : 04-Nov-1999
;; Category          : Utilities/Functions
;; Company           : L.H. Carbide Corporation
;; Author            : Bruce Fisher
;; Function Name     : del_2d_geo
;; Parameters        : Current workplane
;; Purpose           : Delete all 2D Geo on the current wp.
;; SD Revision	   : 7.51
;; Function Rev.	   : 1.00
;; Calling Dialogs   : lhc_hl_bore,
;; Comments          : Creates some bogus 2d geo first so there's no error msg

 (defun del_2d_geo (cwp)
   (circle :cen_rad 0,0 .1)
   (delete_2d :all_2d complete)
)	

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Last modified    : 06-Nov-1999
;; Category         : Utilities/Functions
;; Company          : L.H. Carbide Corporation
;; Author           : Bruce Fisher
;; Function Name    : bld_prt_name
;; SD Revision	  : 7.51
;; Function Rev.	  : 1.00
;; Parameters       : Prt_type, Sz_1, Sz_2, Sz_3
;; Purpose          : Build a string to use for a part name or content ID
;; Calling Dialogs  : 
;; Comments         : Note that the parameters are a string & 3 numbers

 (defun bld_prt_name (PRT_TYPE SZ_1 SZ_2 SZ_3)
    (setq s1_txt (sd-num-to-string SZ_1 4))
    (setq s2_txt (sd-num-to-string SZ_2 4))
    (setq s3_txt (sd-num-to-string SZ_3 4))
    (concatenate 'string prt_type "_" s1_txt "_" s2_txt "_" s3_txt)
  )

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Last modified    : 08-Nov-1999
;; Category         : Utilities/Functions
;; Company          : L.H. Carbide Corporation
;; Author           : Bruce Fisher
;; Function Name    : bld_dwl_name
;; SD Revision	  : 7.51
;; Function Rev.	  : 1.00
;; Parameters       : Prt_type, Sz_1, Sz_2
;; Purpose          : Build a string to use for a part name or content ID
;; Calling Dialogs  : 
;; Comments         : Note that the parameters are a string & 2 numbers

 (defun bld_dwl_name (PRT_TYPE SZ_1 SZ_2)
    (setq s1_txt (sd-num-to-string SZ_1 4))
    (setq s2_txt (sd-num-to-string SZ_2 4))
    (concatenate 'string prt_type "_" s1_txt "_" s2_txt)
  )

