#|

 Lisp-Makro zum automatischen Bohren einer Kegelsenkung fr Senkschrauben
 nach DIN 74

|#

;; Last modified     : 09-Okt-2001
;; Category          : Machining
;; Author            : Michael Mller
;; Company           : PTB-Braunschweig
;; Macro Purpose     : Anfertigen einer Kegelsenkung nach DIN 74
;; Filename          : Kegelsenkung.lsp
;; Revision          : 1.00
;; SD Revision	     : 8.01
;; Platform          : HP-UX
;; Video Mode        : Native
;; Monitor Resolution: 1280x1024

(in-package :LHC)
(use-package :OLI)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; ruft die Funktionen "punch_hl" und "bohre_senk" in "functions.lsp" auf

(sd-create-logical-table 
     "Kegelsenkung-DIN74"
     :columns     '(:Schraube    :Bohr_dm   :Senk_dm    :Senk_tf)
     :columnNames '("Schraube"   "Bohr_dm"  "Senk_dm"   "(Senk_tf)" )
     :types       '(:string      :length    :length     :length )
     :units       '(   nil       :mm        :mm         :mm   )
     
     :contents  '((" M2-Am "	(2.4 :mm)  (4.6 :mm)  (0.0 :mm))
     		  (" M2-Af "	(2.2 :mm)  (4.3 :mm)  (0.25 :mm))
   		     		  
                  (" M3-Am "	(3.4 :mm)  (6.5 :mm)  (0.0 :mm))
     		  (" M3-Af "	(3.2 :mm)  (6.0 :mm)  (0.35 :mm))
    		  (" M3-Bm "	(3.4 :mm)  (6.6 :mm)  (0.0 :mm))
   		  (" M3-Bf "	(3.2 :mm)  (6.3 :mm)  (0.3 :mm))
                  
                  (" M4-Am "	(4.5 :mm)  (8.6 :mm)  (0.0 :mm))
     		  (" M4-Af "	(4.3 :mm)  (8.0 :mm)  (0.4 :mm))
    		  (" M4-Bm "	(4.5 :mm)  (9.0 :mm)  (0.0 :mm))
    		  (" M4-Bf "	(4.3 :mm)  (8.3 :mm)  (0.5 :mm))
                 
                  (" M5-Am "	(5.5 :mm)  (10.4 :mm) (0.0 :mm))
     		  (" M5-Af "	(5.3 :mm)  (10.0 :mm) (0.4 :mm))
     		  (" M5-Bm "	(5.5 :mm)  (11.0 :mm) (0.0 :mm))
     		  (" M5-Bf "	(5.3 :mm)  (10.4 :mm) (0.5 :mm))
                 
                  (" M6-Am "	(6.6 :mm)  (12.4 :mm) (0.0 :mm))
   		  (" M6-Af "	(6.4 :mm)  (11.5 :mm) (0.55 :mm))
     		  (" M6-Bm "	(6.6 :mm)  (13.0 :mm) (0.0 :mm))
    		  (" M6-Bf "	(6.4 :mm)  (12.4 :mm) (0.5 :mm))
                 
                  (" M8-Am "	(9.0 :mm)  (16.4 :mm) (0.0 :mm))
		  (" M8-Af "	(8.4 :mm)  (15.0 :mm) (0.8 :mm))
		  (" M8-Bm "	(9.0 :mm)  (17.2 :mm) (0.0 :mm))
		  (" M8-Bf "	(8.4 :mm)  (16.5 :mm) (0.5 :mm))
                  
                  (" M10-Am "	(11.0 :mm) (20.4 :mm) (0.0 :mm))
		  (" M10-Af "	(10.5 :mm) (19.0 :mm) (0.8 :mm))
		  (" M10-Bm "	(11.0 :mm) (21.5 :mm) (0.0 :mm))
		  (" M10-Bf "	(10.5 :mm) (20.5 :mm) (0.6 :mm))
                  
                  (" M12-Am "   (13.5 :mm) (23.9 :mm) (0.0 :mm))
		  (" M12-Af "   (13.0 :mm) (23.0 :mm) (0.8 :mm))
		  (" M12-Bm "   (13.5 :mm) (25.5 :mm) (0.0 :mm))
		  (" M12-Bf "   (13.0 :mm) (25.0 :mm) (0.6 :mm))
                  
                  (" M16-Am "   (17.5 :mm) (31.9 :mm) (0.0 :mm))
		  (" M16-Af "   (17.0 :mm) (30.0 :mm) (1.3 :mm))
		  (" M16-Bm "   (17.5 :mm) (31.5 :mm) (0.0 :mm))
		  (" M16-Bf "   (17.0 :mm) (31.0 :mm) (0.6 :mm))
                
                  (" M20-Am "  	(22.0 :mm) (40.4 :mm) (0.0 :mm))
                  (" M20-Af "  	(21.0 :mm) (37.0 :mm) (1.8 :mm))
                  (" M20-Bm "  	(22.0 :mm) (38.0 :mm) (0.0 :mm))
                  (" M20-Bf "  	(21.0 :mm) (37.0 :mm) (0.6 :mm))
                 )
 )

(sd-create-display-table
     "Kegelsenkung-DIN74"
     :tableTitle "Kegelsenkung-DIN74"
     :logicalTable  "Kegelsenkung-DIN74"
     :columns     '(:Schraube  :Bohr_dm   :Senk_dm   :Senk_tf)
     :applyColumns          '(:Bohr_dm :Senk_dm :Senk_tf)
     :displayHeight 580
     :filterStatusLine       nil
     :selectionMode          :single-row 
     :applyAction            :default-tokens
)


(defun lhc-show-k_bore-table ()
  (sd-show-display-table "Kegelsenkung-DIN74"
                              :position '("TOP-MENU-TOOLBOX-TB"
                                                       :bottomleft  330 250)
  )
)

(defun lhc-hide-k_bore-table ()
  (sd-hide-display-table "Kegelsenkung-DIN74" :ignorePin t))


(sd-defdialog 'kegelsenkung
  :dialog-title "Kegl.-Senk."
  :variables
  '((POINT_LIST)
   (A_PART 
            :value-type :part-incl-new
	      :modifies :contents 
	      :title "Teil"
	      :prompt-text "zu bohrendes Teil.")
    (A_WP   
            :value-type :wp 
	      :title "AE"
	      :prompt-text "AE angeben.")
    (PNT_1 
            :value-type :point-2d  ; alter Wert :point-3d-pick
            :title "Punkt"
            :toggle-type :invisible
            :prompt-text "Punkt auswaehlen oder Back."
            :after-input (progn
                (push-point pnt_1)
                (sd-call-cmds (c_point pnt_1)))
    )  
    (TMP_NUM
              :initial-value 0)
    (NM_HLS
            :title "Anzahl"
            :value-type :display-only
            :initial-value 0
            :display-units :length) 


    (Bohr_dm 
              :value-type :positive-number
              :title "Bohr_dm."
              :show-input-tool (lhc-show-k_bore-table)
              :hide-input-tool (lhc-hide-k_bore-table)  
              :prompt-text "Bohrungsdurchmesser eingeben."
              :after-input
                (setq Table_values (sd-read-logical-table-row
                                 "Kegelsenkung-DIN74"
                                 :pList `(:Bohr_dm, Bohr_dm)
                                 :units  :internal
                             )
                Senk_dm   (getf Table_values :Senk_dm)
                Senk_tf     (getf Table_values :Senk_tf)
                 )
    )
    (SENK_DM 
              :value-type :positive-number
              :title "Senk._dm."
              :prompt-text "Senkungsdurchmesser eingeben")
    (SENK_TF 
            :value-type :number
            :title "Senk._tiefe"
            :prompt-text "Senkungstiefe angeben")
    (BACK :push-action (pop-point)))

  :local-functions
    '((PUSH-POINT (a-new-point)
         (push a-new-point point_list)
         (setq tmp_num (+ tmp_num 1))
         (setq nm_hls (* tmp_num 1))
         (push a-new-point point_list)
     )
      (POP-POINT ()
         (pop point_list)
         (setq tmp_num (- tmp_num 1))
         (setq nm_hls (* tmp_num 1))
         (unless point_list
           (sd-set-variable-status 'back :enable nil)))

     (MAIN-ACTION ()
       (dolist (pnt_1 point_list)
       (punch_hl a_part pnt_1 Bohr_dm))
       (dolist (pnt_1 point_list)
       (bohre_senk a_part pnt_1 Senk_tf Senk_dm))
    ))
  :prompt-variable 'pnt_1
  :ok-action
  '(main-action))
 